@@ -1,7 +1,7 @@
 # ==========================================================================
 #
-# ZoneMinder General Utility Module, $Date: 2008-02-16 18:39:59 +0000 (Sat, 16 Feb 2008) $, $Revision: 2313 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder General Utility Module, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# Copyright (C) 2001-2008  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -45,6 +45,7 @@ our %EXPORT_TAGS = (
 		executeShellCommand
 		getEventPath
 		deleteEventFiles
+        makePath
 	) ]
 );
 push( @{$EXPORT_TAGS{all}}, @{$EXPORT_TAGS{$_}} ) foreach keys %EXPORT_TAGS;
@@ -149,6 +150,32 @@ sub deleteEventFiles( $;$ )
     }
 }
 
+sub makePath( $$ )
+{
+    my $root = shift;
+    my $path = shift;
+
+    Debug( "Creating path '$path'\n" );
+    my @parts = split( '/', $path );
+    my $subpath = $root;
+    foreach my $dir ( @parts )
+    {
+        $subpath .= '/'.$dir;
+        if ( !-d $subpath )
+        {
+            if ( -e $subpath )
+            {
+                die( "Can't create '$subpath', already exists as non directory" );
+            }
+            else
+            {
+                Debug( "Creating '$subpath'\n" );
+                mkdir( $subpath ) or die( "Can't mkdir '$subpath': $!" );
+            }
+        }
+    }
+}
+
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
@@ -193,7 +220,7 @@ Philip Coombes, E<lt>philip.coombes@zoneminder.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Philip Coombes
+Copyright (C) 2001-2008  Philip Coombes
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.3 or,
