@@ -2,7 +2,7 @@
 #
 # ==========================================================================
 #
-# ZoneMinder Audit Script, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# ZoneMinder Audit Script, $Date: 2009-06-08 10:11:56 +0100 (Mon, 08 Jun 2009) $, $Revision: 2908 $
 # Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -52,6 +52,7 @@ use constant DBG_LEVEL => 0; # 0 is errors, warnings and info only, > 0 for debu
 #
 # ==========================================================================
 
+use lib '/home/stan/Work/Install/lib/perl5/site_perl/5.8.8'; # Include custom perl install path
 use ZoneMinder;
 use DBI;
 use POSIX;
@@ -309,7 +310,8 @@ do
 		}
 	}
 
-	my $sql7 = "select distinct EventId from Frames left join Events on Frames.EventId = Events.Id where isnull(Events.Id) group by EventId";
+	#my $sql7 = "select distinct EventId from Frames left join Events on Frames.EventId = Events.Id where isnull(Events.Id) group by EventId";
+	my $sql7 = "select distinct EventId from Frames where EventId not in (select Id from Events)";
 	my $sth7 = $dbh->prepare_cached( $sql7 ) or Fatal( "Can't prepare '$sql7': ".$dbh->errstr() );
 	$res = $sth7->execute() or Fatal( "Can't execute: ".$sth7->errstr() );
 	while( my $frame = $sth7->fetchrow_hashref() )
@@ -322,7 +324,8 @@ do
 	}
     $sth7->finish();
 
-	my $sql8 = "select distinct EventId from Stats left join Events on Stats.EventId = Events.Id where isnull(Events.Id) group by EventId";
+	#my $sql8 = "select distinct EventId from Stats left join Events on Stats.EventId = Events.Id where isnull(Events.Id) group by EventId";
+	my $sql8 = "select distinct EventId from Stats where EventId not in (select Id from Events)";
 	my $sth8 = $dbh->prepare_cached( $sql8 ) or Fatal( "Can't prepare '$sql8': ".$dbh->errstr() );
 	$res = $sth8->execute() or Fatal( "Can't execute: ".$sth8->errstr() );
 	while( my $stat = $sth8->fetchrow_hashref() )
