@@ -1,6 +1,6 @@
 /*
- * ZoneMinder Debug Interface, $Date: 2006-01-17 10:56:30 +0000 (Tue, 17 Jan 2006) $, $Revision: 1829 $
- * Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+ * ZoneMinder Debug Interface, $Date: 2009-02-17 21:22:02 +0000 (Tue, 17 Feb 2009) $, $Revision: 2773 $
+ * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */  
 
+#ifndef ZM_DEBUG_H
+#define ZM_DEBUG_H
+
 #include <sys/types.h>	
 #include <limits.h>	
 
@@ -37,29 +40,31 @@
 /* Define the level at which messages go through syslog */
 #define ZM_DBG_SYSLOG		ZM_DBG_INF 
 
-#define zmDbgPrintf(level,params)	{\
+#define zmDbgPrintf(level,params...)	{\
 					if (level <= zm_dbg_level)\
-					{\
-						(void) zmDbgPrepare(__FILE__,__LINE__,level);\
-						(void) zmDbgOutput params;\
-					}\
+						zmDbgOutput( 0, __FILE__, __LINE__, level, ##params );\
+				}
+
+#define zmDbgHexdump(level,data,len)	{\
+					if (level <= zm_dbg_level)\
+						zmDbgOutput( 1, __FILE__, __LINE__, level, "%p (%d)", data, len );\
 				}
 
 /* Turn off debug here */
 #ifndef ZM_DBG_OFF
-#define Debug(level,params)	zmDbgPrintf(level,params)
+#define Debug(level,params...)	zmDbgPrintf(level,##params)
+#define Hexdump(level,data,len)	zmDbgHexdump(level,data,len)
 #else
-#define Debug(level,params)
+#define Debug(level,params...)
+#define Hexdump(level,data,len)
 #endif
 
-#define Info(params)		zmDbgPrintf(0, params)
-#define Warning(params)		zmDbgPrintf(ZM_DBG_WAR,params)
-#define Error(params)		zmDbgPrintf(ZM_DBG_ERR,params)
-#define Fatal(params)		zmDbgPrintf(ZM_DBG_FAT,params)
-#define Entrypoint(params)	zmDbgPrintf(9,params);
-#define Exitpoint(params)	zmDbgPrintf(9,params);
-#define Mark()				Info(("Mark/%s/%d", __FILE__, __LINE__ ))
-#define Log()				Info(("Log"))
+#define Info(params...)		zmDbgPrintf(ZM_DBG_INF,##params)
+#define Warning(params...)	zmDbgPrintf(ZM_DBG_WAR,##params)
+#define Error(params...)	zmDbgPrintf(ZM_DBG_ERR,##params)
+#define Fatal(params...)	zmDbgPrintf(ZM_DBG_FAT,##params)
+#define Mark()				Info("Mark/%s/%d",__FILE__,__LINE__)
+#define Log()				Info("Log")
 #ifdef __GNUC__
 #define Enter(level)		zmDbgPrintf(level,("Entering %s",__PRETTY_FUNCTION__))
 #define Exit(level)			zmDbgPrintf(level,("Exiting %s",__PRETTY_FUNCTION__))
@@ -72,24 +77,6 @@
 #define Exit(level)			
 #endif
 
-#define HexDump(level,t,n)	{if(level<=zm_dbg_level)	\
-							{	\
-								int _i;	\
-								int _len;	\
-								char *_s;	\
-								_s = (t);	\
-								_len = (n);	\
-								for(_i = 0; _i < _len; _i++,_s++)	\
-								{	\
-									if(!(_i % 16))	\
-									{	\
-										fprintf(zm_dbg_log_fd,"\n");	\
-									}	\
-									fprintf(zm_dbg_log_fd,"0x%02x ",	\
-												((int)*_s)&0xff);	\
-								}	\
-								fprintf(zm_dbg_log_fd,"\n");	\
-							}}
 #ifdef __cplusplus
 extern "C" {
 #endif 
@@ -107,14 +94,12 @@ void zmDbgSubtractTime( struct timeval * const tp1, struct timeval * const tp2 )
 int zmDbgInit( const char *name, const char *id, int level );
 int zmDbgReinit( const char *target );
 int zmDbgTerm(void);
-int zmDbgPrepare( const char * const file, const int line, const int level );
-int zmDbgOutput( const char *fstring, ... ) __attribute__ ((format(printf, 1, 2)));
+void zmDbgOutput( int hex, const char * const file, const int line, const int level, const char *fstring, ... ) __attribute__ ((format(printf, 5, 6)));
 #else
 int zmDbgInit();
 int zmDbgReinit();
 int zmDbgTerm();
-int zmDbgPrepare();
-int zmDbgOutput();
+void zmDbgOutput();
 #endif
 
 extern int zm_dbg_level;
@@ -133,3 +118,5 @@ extern int zm_dbg_add_log_id;
 #ifdef __cplusplus
 } /* extern "C" */
 #endif
+
+#endif // ZM_DEBUG_H
