@@ -1,5 +1,5 @@
 //
-// ZoneMinder Event Class Implementation, $Date: 2009-01-21 17:37:39 +0000 (Wed, 21 Jan 2009) $, $Revision: 2718 $
+// ZoneMinder Event Class Implementation, $Date: 2009-05-08 14:47:19 +0100 (Fri, 08 May 2009) $, $Revision: 2867 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -1034,18 +1034,18 @@ void EventStream::processCommand( const CmdMsg *msg )
     }
     struct {
         int event;
-        bool paused;
-        time_t progress;
+        int progress;
         int rate;
         int zoom;
+        bool paused;
     } status_data;
 
     status_data.event = event_data->event_id;
-    status_data.paused = paused;
-    status_data.progress = event_data->frames[curr_frame_id-1].offset;
+    status_data.progress = (int)event_data->frames[curr_frame_id-1].offset;
     status_data.rate = replay_rate;
     status_data.zoom = zoom;
-    Debug( 2, "E:%d, P:%d, p:%ld R:%d, Z:%d",
+    status_data.paused = paused;
+    Debug( 2, "E:%d, P:%d, p:%d R:%d, Z:%d",
         status_data.event,
         status_data.paused,
         status_data.progress,
@@ -1235,7 +1235,7 @@ bool EventStream::sendFrame( int delta_us )
                 break;
         }
         fprintf( stdout, "Content-Length: %d\r\n\r\n", img_buffer_size );
-        if ( fwrite( img_buffer, img_buffer_size, 1, stdout ) < 0 )
+        if ( fwrite( img_buffer, img_buffer_size, 1, stdout ) != 1 )
         {
             Error( "Unable to send stream frame: %s", strerror(errno) );
             return( false );
@@ -1329,7 +1329,7 @@ void EventStream::runStream()
             {
                 delta_us = (unsigned int)(frame_data->delta * 1000000);
                 if ( effective_fps < base_fps )
-                    delta_us = (delta_us * base_fps)/effective_fps;
+                    delta_us = (unsigned int)((delta_us * base_fps)/effective_fps);
                 send_frame = true;
             }
         }
