@@ -1,5 +1,5 @@
 //
-// ZoneMinder Image Class Implementation, $Date: 2009-02-16 18:17:19 +0000 (Mon, 16 Feb 2009) $, $Revision: 2762 $
+// ZoneMinder Image Class Implementation, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
 #include "zm_image.h"
 
 #include <sys/stat.h>
+#include <errno.h>
 
 #define ABSDIFF(a,b) 	(((a)<(b))?((b)-(a)):((a)-(b)))
 
@@ -294,7 +295,7 @@ bool Image::WriteRaw( const char *filename ) const
 		return( false );
 	}
 
-	if ( fwrite( buffer, size, 1, outfile ) < 1 )
+	if ( fwrite( buffer, size, 1, outfile ) != 1 )
     {
         Error( "Unable to write to '%s': %s", filename, strerror(errno) );
         return( false );
@@ -381,7 +382,7 @@ bool Image::WriteJpeg( const char *filename, int quality_override ) const
 	{
 		Image temp_image( *this );
 		temp_image.Colourise();
-		return( temp_image.WriteJpeg( filename ) );
+		return( temp_image.WriteJpeg( filename, quality_override ) );
 	}
 
 	int quality = quality_override?quality_override:config.jpeg_file_quality;
@@ -554,6 +555,7 @@ bool Image::EncodeJpeg( JOCTET *outbuffer, int *outbuffer_size, int quality_over
 	return( true );
 }
 
+#if HAVE_ZLIB_H
 bool Image::Unzip( const Bytef *inbuffer, unsigned long inbuffer_size )
 {
 	unsigned long zip_size = size;
@@ -581,6 +583,7 @@ bool Image::Zip( Bytef *outbuffer, unsigned long *outbuffer_size, int compressio
 	}
 	return( true );
 }
+#endif // HAVE_ZLIB_H
 
 bool Image::Crop( int lo_x, int lo_y, int hi_x, int hi_y )
 {
