@@ -1,6 +1,6 @@
 /*
- * ZoneMinder JPEG memory encoding/decoding, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
- * Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+ * ZoneMinder JPEG memory encoding/decoding, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+ * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,10 +35,10 @@ void zm_jpeg_error_exit( j_common_ptr cinfo )
 
 	(zmerr->pub.format_message)( cinfo, buffer ); 
 
-	Error(( "%s", buffer ));
+	Error( "%s", buffer );
 	if ( ++jpeg_err_count == MAX_JPEG_ERRS )
 	{
-		Fatal(( "Maximum number (%d) of JPEG errors reached, exiting", jpeg_err_count ));
+		Fatal( "Maximum number (%d) of JPEG errors reached, exiting", jpeg_err_count );
 		exit( -1 );
 	}
 
@@ -59,7 +59,7 @@ void zm_jpeg_emit_message( j_common_ptr cinfo, int msg_level )
 		if ( zmerr->pub.num_warnings == 0 || zmerr->pub.trace_level >= 3 )
 		{
 			(zmerr->pub.format_message)( cinfo, buffer ); 
-			Warning(( "%s", buffer ));
+			Warning( "%s", buffer );
 		}
 		/* Always count warnings in num_warnings. */
 		zmerr->pub.num_warnings++;
@@ -70,7 +70,7 @@ void zm_jpeg_emit_message( j_common_ptr cinfo, int msg_level )
 		if ( zmerr->pub.trace_level >= msg_level )
 		{
 			(zmerr->pub.format_message)( cinfo, buffer ); 
-			Debug( msg_level, ( "%s", buffer ) );
+			Debug( msg_level, "%s", buffer );
 		}
 	}
 }
