@@ -1,5 +1,5 @@
 /*
- * ZoneMinder MPEG class implementation, $Date: 2008-10-29 23:08:21 +0000 (Wed, 29 Oct 2008) $, $Revision: 2679 $
+ * ZoneMinder MPEG class implementation, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@ void VideoStream::SetupFormat( const char *p_filename, const char *p_format )
 	of = guess_format( format, NULL, NULL);
 	if ( !of )
 	{
-		Warning( "Could not deduce output format from file extension: using MPEG." );
+		Warning( "Could not deduce output format from file extension: using mpeg" );
 		of = guess_format("mpeg", NULL, NULL);
 	}
 	if ( !of )
@@ -67,7 +67,7 @@ void VideoStream::SetupFormat( const char *p_filename, const char *p_format )
 	snprintf( ofc->filename, sizeof(ofc->filename), "%s", filename );
 }
 
-void VideoStream::SetupCodec( int colours, int width, int height, int bitrate, int frame_rate )
+void VideoStream::SetupCodec( int colours, int width, int height, int bitrate, double frame_rate )
 {
 	pf = (colours==1?PIX_FMT_GRAY8:PIX_FMT_RGB24);
 
@@ -102,14 +102,14 @@ void VideoStream::SetupCodec( int colours, int width, int height, int bitrate, i
 		   of which frame timestamps are represented. for fixed-fps content,
 		   timebase should be 1/framerate and timestamp increments should be
 		   identically 1. */
-		c->time_base.den = frame_rate;
-		c->time_base.num = 1;
+		c->time_base.den = (int)(frame_rate*100);
+		c->time_base.num = 100;
 #else
 		/* frames per second */
 		c->frame_rate = frame_rate;
 		c->frame_rate_base = 1;
 #endif
-		c->gop_size = frame_rate/2; /* emit one intra frame every half second or so */
+		//c->gop_size = frame_rate/2; /* emit one intra frame every half second or so */
 		c->gop_size = 12;
 		if ( c->gop_size < 3 )
 			c->gop_size = 3;
@@ -233,7 +233,7 @@ void VideoStream::OpenStream()
 	av_write_header(ofc);
 }
 
-VideoStream::VideoStream( const char *filename, const char *format, int bitrate, int frame_rate, int colours, int width, int height )
+VideoStream::VideoStream( const char *filename, const char *format, int bitrate, double frame_rate, int colours, int width, int height )
 {
 	if ( !initialised )
 	{
@@ -378,7 +378,7 @@ double VideoStream::EncodeFrame( uint8_t *buffer, int buffer_size, bool add_time
 	}
 	if ( ret != 0 )
 	{
-		Fatal( "Error %d while writing video frame", ret );
+		Fatal( "Error %d while writing video frame: %s", ret, strerror( errno ) );
 	}
 	return( pts );
 }
