@@ -1,6 +1,6 @@
 /*
- * ZoneMinder regular expression class implementation, $Date: 2006-01-17 10:56:30 +0000 (Tue, 17 Jan 2006) $, $Revision: 1829 $
- * Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+ * ZoneMinder regular expression class implementation, $Date: 2009-01-28 11:27:35 +0000 (Wed, 28 Jan 2009) $, $Revision: 2727 $
+ * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,16 +30,16 @@ RegExpr::RegExpr( const char *pattern, int flags, int p_max_matches ) : max_matc
 	int erroffset = 0;
 	if ( !(regex = pcre_compile( pattern, flags, &errstr, &erroffset, 0 )) )
 	{
-		Fatal(( "pcre_compile(%s): %s at %d", pattern, errstr, erroffset ));
+		Fatal( "pcre_compile(%s): %s at %d", pattern, errstr, erroffset );
 	}
 
 	regextra = pcre_study( regex, 0, &errstr );
 	if ( errstr )
 	{
-		Fatal(( "pcre_study(%s): %s", pattern, errstr ));
+		Fatal( "pcre_study(%s): %s", pattern, errstr );
 	}
 
-	if ( ok = (bool)regex )
+	if ( (ok = (bool)regex) )
 	{
 		match_vectors = new int[3*max_matches];
 		memset( match_vectors, 0, sizeof(*match_vectors)*3*max_matches );
@@ -78,7 +78,7 @@ int RegExpr::Match( const char *subject_string, int subject_length, int flags )
 	{
 		if ( n_matches < PCRE_ERROR_NOMATCH )
 		{
-			Error(( "Error %d executing regular expression", n_matches ));
+			Error( "Error %d executing regular expression", n_matches );
 		}
 		return( n_matches = 0 );
 	}
