@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2009-01-28 09:48:06 +0000 (Wed, 28 Jan 2009) $, $Revision: 2724 $
+// ZoneMinder Remote Camera Class Implementation, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -23,9 +23,10 @@
 
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <errno.h>
 
 RemoteCameraHttp::RemoteCameraHttp( int p_id, const std::string &p_method, const std::string &p_host, const std::string &p_port, const std::string &p_path, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
-    RemoteCamera( p_id, "http", p_host, p_port, p_path, "", p_width, p_height, p_colours, p_brightness, p_contrast, p_hue, p_colour, p_capture )
+    RemoteCamera( p_id, "http", p_host, p_port, p_path, p_width, p_height, p_colours, p_brightness, p_contrast, p_hue, p_colour, p_capture )
 {
 	sd = -1;
 
