@@ -1,5 +1,5 @@
 //
-// ZoneMinder General Utility Functions, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder General Utility Functions, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -17,6 +17,7 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
 
+//#include "zm_debug.h"
 #include "zm_utils.h"
 
 #include <stdarg.h>
@@ -56,24 +57,36 @@ bool startsWith( const std::string &haystack, const std::string &needle )
     return( haystack.substr( 0, needle.length() ) == needle );
 }
 
-StringVector split( const std::string &string, const std::string chars )
+StringVector split( const std::string &string, const std::string chars, int limit )
 {
     StringVector stringVector;
     std::string tempString = string;
     std::string::size_type startIndex = 0;
     std::string::size_type endIndex = 0;
 
+    //Info( "Looking for '%s' in '%s', limit %d", chars.c_str(), string.c_str(), limit );
     do
     {
         // Find delimiters
         endIndex = string.find_first_of( chars, startIndex );
+        //Info( "Got endIndex at %d", endIndex );
         if ( endIndex > 0 )
+        {
+            //Info( "Adding '%s'", string.substr( startIndex, endIndex-startIndex ).c_str() );
             stringVector.push_back( string.substr( startIndex, endIndex-startIndex ) );
+        }
         if ( endIndex == std::string::npos )
             break;
         // Find non-delimiters
         startIndex = tempString.find_first_not_of( chars, endIndex );
+        if ( limit && (stringVector.size() == (limit-1)) )
+        {
+            stringVector.push_back( string.substr( startIndex ) );
+            break;
+        }
+        //Info( "Got new startIndex at %d", startIndex );
     } while ( startIndex != std::string::npos );
+    //Info( "Finished with %d strings", stringVector.size() );
 
     return( stringVector );
 }
