@@ -1,5 +1,5 @@
 //
-// ZoneMinder General Utility Functions, $Date: 2008-10-22 14:10:12 +0100 (Wed, 22 Oct 2008) $, $Revision: 2670 $
+// ZoneMinder General Utility Functions, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@ const std::string stringtf( const char *format, ... );
 const std::string stringtf( const std::string &format, ... );
 
 bool startsWith( const std::string &haystack, const std::string &needle );
-StringVector split( const std::string &string, const std::string chars );
+StringVector split( const std::string &string, const std::string chars, int limit=0 );
 
 const std::string base64Encode( const std::string &inString );
 
