@@ -1,5 +1,5 @@
 //
-// ZoneMinder Zone Class Implementation, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Zone Class Implementation, $Date: 2009-05-25 19:03:46 +0100 (Mon, 25 May 2009) $, $Revision: 2890 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -85,7 +85,7 @@ void Zone::Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_
 					ranges[py].lo_x = x;
 					ranges[py].off_x = px;
 				}
-				else if ( ranges[py].hi_x < x )
+				if ( ranges[py].hi_x < x )
 				{
 					ranges[py].hi_x = x;
 				}
