@@ -1,6 +1,6 @@
 //
-// ZoneMinder Image File Write Class Interface, $Date: 2006/01/17 10:56:30 $, $Revision: 1.6 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Image File Write Class Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -16,13 +16,14 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
-#include <mysql/mysql.h>
+
 #ifndef ZMFILE_H
 #define ZMFILE_H
 
 struct FrameHeader
 {
 	unsigned long event_id;
+    time_t event_time;
 	unsigned long frame_id;
 	bool alarm_frame;
 	unsigned long image_length;
