@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web database interface file, $Date: 2008-12-05 23:15:08 +0000 (Fri, 05 Dec 2008) $, $Revision: 2705 $
+// ZoneMinder web database interface file, $Date: 2009-03-31 11:53:51 +0100 (Tue, 31 Mar 2009) $, $Revision: 2825 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -205,6 +205,13 @@ function getTableColumns( $table, $asString=1 )
     return( $columns );  
 }               
 
+function getTableAutoInc( $table )
+{
+    $sql = "show table status where Name = '".dbEscape($table)."'";
+    $row = dbFetchOne( $sql );
+    return( $row['Auto_increment'] );
+}
+
 function dbFetchMonitor( $mid )
 {
     return( dbFetchOne( "select * from Monitors where Id = '".dbEscape($mid)."'" ) );
