@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web function library, $Date: 2009-02-19 14:06:39 +0000 (Thu, 19 Feb 2009) $, $Revision: 2781 $
+// ZoneMinder web function library, $Date: 2009-05-06 10:48:01 +0100 (Wed, 06 May 2009) $, $Revision: 2860 $
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -767,7 +767,7 @@ function getFormChanges( $values, $newValues, $types=false, $columns=false )
             }
             default :
             {
-                if ( empty($values[$key]) || ($values[$key] != $value) )
+                if ( !isset($values[$key]) || ($values[$key] != $value) )
                 {
                     $changes[$key] = "$key = '".dbEscape($value)."'";
                 }
@@ -777,11 +777,21 @@ function getFormChanges( $values, $newValues, $types=false, $columns=false )
     }
     foreach( $values as $key=>$value )
     {
-        if ( !empty($columns[$key]) && !empty($types[$key]) && $types[$key] == 'toggle' )
+        if ( !empty($columns[$key]) )
         {
-            if ( !isset($newValues[$key]) && !empty($value) )
+            if ( !empty($types[$key]) )
             {
-                $changes[$key] = "$key = 0";
+                if ( $types[$key] == 'toggle' )
+                {
+                    if ( !isset($newValues[$key]) && !empty($value) )
+                    {
+                        $changes[$key] = "$key = 0";
+                    }
+                }
+                else if ( $types[$key] == 'set' )
+                {
+                    $changes[$key] = "$key = ''";
+                }
             }
         }
     }
@@ -1447,7 +1457,7 @@ function parseFilter( &$filter, $saveToSession=false, $querySep='&' )
             {
                 $filter['query'] .= $querySep."filter[terms][$i][cbr]=".urlencode($filter['terms'][$i]['cbr']);
                 $filter['sql'] .= " ".str_repeat( ")", $filter['terms'][$i]['cbr'] )." ";
-                $filter['fields'] .= "<input type=\"hidden\" \"name=filter[terms][$i][cbr]\" value=\"".htmlspecialchars($filter['terms'][$i]['cbr'])."\"/>\n";
+                $filter['fields'] .= "<input type=\"hidden\" name=filter[terms][$i][cbr]\" value=\"".htmlspecialchars($filter['terms'][$i]['cbr'])."\"/>\n";
             }
         }
         if ( $filter['sql'] )
@@ -2132,19 +2142,22 @@ function setDeviceStatusX10( $key, $status )
 
 function isVector ( &$array )
 {
-    $nextKey = 0;
+    $next_key = 0;
     foreach ( array_keys($array) as $key )
     {
         if ( !is_int( $key ) )
             return( false );
-        if ( $key != $nextKey++ )
+        if ( $key != $next_key++ )
             return( false );
     }
     return( true );
 }
 
-function jsValue( &$value )
+function jsonEncode( &$value )
 {
+    if ( function_exists('json_encode') )
+        return( json_encode( $value ) );
+
     switch ( gettype($value) )
     {
         case 'double':
@@ -2153,14 +2166,14 @@ function jsValue( &$value )
         case 'boolean':
             return( $value?'true':'false' );
         case 'string':
-            return( "'".addslashes(preg_replace( "/\n\r?/",'\n',$value))."'" );
+            return( '"'.preg_replace( "/\r?\n/", '\\n', addcslashes($value,'"\'\\/') ).'"' );
         case 'NULL':
             return( 'null' );
         case 'object':
-            return( "'Object ".addslashes(get_class($value))."'" );
+            return( '"Object '.addcslashes(get_class($value),'"\'\\/').'"' );
         case 'array':
             if ( isVector( $value ) )
-                return( '['.join( ',', array_map( 'jsValue', $value) ).']' );
+                return( '['.join( ',', array_map( 'jsonEncode', $value) ).']' );
             else
             {
                 $result = '{';
@@ -2168,12 +2181,12 @@ function jsValue( &$value )
                 {
                     if ( $result != '{' )
                         $result .= ',';
-                    $result .= jsValue( $subkey ).':'.jsValue( $subvalue );
+                    $result .= jsonEncode( $subkey ).':'.jsonEncode( $subvalue );
                 }
                 return( $result.'}' );
             }
         default:
-            return( "'".addslashes(preg_replace( "/\n\r?/",'\n',$value))."'" );
+            return( '"'.addcslashes(gettype($value),'"\'\\/').'"' );
     }
 }
 
@@ -2192,7 +2205,7 @@ function ajaxError( $message, $code=HTTP_STATUS_OK )
     {
         $response = array( 'result'=>'Error', 'message'=>$message );
         header( "Content-type: text/plain" );
-        exit( jsValue( $response ) );
+        exit( jsonEncode( $response ) );
     }
     header( "HTTP/1.0 $code $message" );
     exit();
@@ -2209,7 +2222,7 @@ function ajaxResponse( $result=false )
         $response['message'] = $result;
     //error_log( var_export( $response, true ) );
     header( "Content-type: text/plain" );
-    exit( jsValue( $response ) );
+    exit( jsonEncode( $response ) );
 }
 
 function generateConnKey()
