@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Chinese Traditional language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Chinese Traditional language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -68,10 +68,10 @@
  //setlocale( LC_ALL, 'en_GB' ); All locale settings 4.3.0 and after
 // setlocale( LC_CTYPE, 'en_GB' ); Character class settings 4.3.0 and after
 // setlocale( LC_TIME, 'en_GB' ); Date and time formatting 4.3.0 and after
-setlocale( 'LC_ALL', 'Big5' ); //All locale settings pre-4.3.0
+setlocale( LC_ALL, 'Big5' ); //All locale settings pre-4.3.0
 //setlocale( LC_ALL, 'Big5' ); //All locale settings 4.3.0 and after
-setlocale( 'LC_CTYPE', 'Big5' ); //Character class settings 4.3.0 and after
-setlocale( 'LC_TIME', 'Big5' ); //Date and time formatting 4.3.0 and after
+setlocale( LC_CTYPE, 'Big5' ); //Character class settings 4.3.0 and after
+setlocale( LC_TIME, 'Big5' ); //Date and time formatting 4.3.0 and after
 
 // Simple String Replacements
 $SLANG = array(
@@ -123,6 +123,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Weekday',
     'Auto'                 => '自動',
     'AutoStopTimeout'      => '時間過自動停止',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => '平均<br/>分數',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -140,6 +141,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Names may only contain alphanumeric characters plus hyphen and underscore',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -203,6 +205,7 @@ $SLANG = array(
     'CaptureWidth'         => '捕捉寬度',
     'Cause'                => '因素',
     'CheckMethod'          => 'Alarm Check Method',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Choose Filter',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => '關閉',
@@ -237,6 +240,7 @@ $SLANG = array(
     'DeleteAndPrev'        => '刪除 &amp; 上一事件',
     'DeleteSavedFilter'    => '刪除儲存過濾',
     'Description'          => '描述',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => '裝置通道',
     'DeviceFormat'         => '裝置格式',
@@ -256,6 +260,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => '下載',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => '歷時',
     'Edit'                 => '編輯',
     'Email'                => 'Email',
@@ -438,6 +443,8 @@ $SLANG = array(
     'MonitorIds'           => 'Monitor&nbsp;Ids',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => '監視',
     'Montage'              => '全部顯示',
     'Month'                => '月',
@@ -458,6 +465,7 @@ $SLANG = array(
     'NewUser'              => '新使用者',
     'Next'                 => '下一步',
     'No'                   => 'No',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'There are no frames recorded for this event',
     'NoGroup'              => 'No Group',               // Added - 2009-02-08
     'NoSavedFilters'       => 'NoSavedFilters',
@@ -512,6 +520,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => '上一事件',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Rate',
     'Real'                 => 'Real',
@@ -811,4 +820,3 @@ $OLANG = array(
 );
 
 ?>
-
