@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web German language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web German language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -119,6 +119,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Wochentag',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto-Stopp-Zeit&uuml;berschreitung',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Mittlere<br/>Punktzahl',
     'Background'           => 'Hintergrund',
     'BackgroundFilter'     => 'Filter im Hintergrund laufen lassen',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'            => 'Die y-Koordinate der Bezeichnung muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadMaxFPS'            => 'Maximum-FPS muss eine positive Ganzzahl oder eine Gleitkommazahl sein',
     'BadNameChars'         => 'Namen d&uuml;rfen nur aus Buchstaben, Zahlen und Trenn- oder Unterstrichen bestehen',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Der Pfad muss auf einen g&uuml;ltigen Wert eingestellt sein',
     'BadPort'              => 'Der Port muss auf eine g&uuml;ltige Zahl eingestellt sein',
     'BadPostEventCount'    => 'Der Z&auml;hler f&uuml;r die Ereignisfolgebilder muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
@@ -199,6 +201,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Erfasse Breite',
     'Cause'                => 'Grund',
     'CheckMethod'          => 'Alarm-Pr&uuml;fmethode',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Filterauswahl',
     'ChoosePreset'         => 'Voreinstellung ausw&auml;hlen',
     'Close'                => 'Schlie&szlig;en',
@@ -233,6 +236,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'L&ouml;schen &amp; Vorheriges',
     'DeleteSavedFilter'    => 'L&ouml;sche gespeichertes Filter',
     'Description'          => 'Beschreibung',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Ger&auml;tekanal',
     'DeviceFormat'         => 'Ger&auml;teformat',
@@ -252,6 +256,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Noch nicht, erinnere mich in einer Woche noch mal.',
     'DonateYes'            => 'Ja, ich m&ouml;chte jetzt spenden.',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Dauer',
     'Edit'                 => 'Bearbeiten',
     'Email'                => 'E-Mail',
@@ -434,6 +439,8 @@ $SLANG = array(
     'MonitorIds'           => 'Monitor-ID',
     'MonitorPreset'        => 'Monitor-Voreinstellung',
     'MonitorPresetIntro'   => 'W&auml;hlen Sie eine geeignete Voreinstellung aus der folgenden Liste.<br><br>Bitte beachten Sie, dass dies m&ouml;gliche Einstellungen von Ihnen am Monitor &uuml;berschreiben kann.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitore',
     'Montage'              => 'Montage',
     'Month'                => 'Monat',
@@ -454,6 +461,7 @@ $SLANG = array(
     'NewUser'              => 'Neuer Benutzer',
     'Next'                 => 'N&auml;chstes',
     'No'                   => 'Nein',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Es gibt keine Aufnahmen von diesem Ereignis.',
     'NoGroup'              => 'Keine Gruppe',
     'NoSavedFilters'       => 'Keine gespeicherten Filter',
@@ -508,6 +516,7 @@ $SLANG = array(
     'Preset'               => 'Voreinstellung',
     'Presets'              => 'Voreinstellungen',
     'Prev'                 => 'Vorheriges',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protokoll',
     'Rate'                 => 'Abspielgeschwindigkeit',
     'Real'                 => 'Real',
@@ -807,4 +816,3 @@ $OLANG = array(
 );
 
 ?>
-
