@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Danish language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Danish language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -120,6 +120,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Uge Dag',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Avg.<br/>Skore',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -137,6 +138,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Navne m kun indeholde alphanumeric karaktere plus hyphen og underscore',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -200,6 +202,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Capture Width',
     'Cause'                => 'rsag',
     'CheckMethod'          => 'Alarm Check Methode',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Vlg Filter',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => 'Luk',
@@ -234,6 +237,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Slet &amp; Forrige',
     'DeleteSavedFilter'    => 'Slet Gemte filter',
     'Description'          => 'Beskrivelse',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Enheds Kanal',
     'DeviceFormat'         => 'Enheds Format',
@@ -253,6 +257,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Forlb',
     'Edit'                 => 'Rediger',
     'Email'                => 'Email',
@@ -435,6 +440,8 @@ $SLANG = array(
     'MonitorIds'           => 'Monitor&nbsp;Ids',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitore',
     'Montage'              => 'Montage',
     'Month'                => 'Mned',
@@ -455,6 +462,7 @@ $SLANG = array(
     'NewUser'              => 'Ny User',
     'Next'                 => 'Nste',
     'No'                   => 'Nej',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Der er ingen billeder optaget for denne event',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'NoSavedFilters',
@@ -509,6 +517,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Prev',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Rate',
     'Real'                 => 'Real',
@@ -808,4 +817,3 @@ $OLANG = array(
 );
 
 ?>
-
