@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2009-01-27 11:07:24 +0000 (Tue, 27 Jan 2009) $, $Revision: 2723 $
+// ZoneMinder web UK English language file, $Date: 2009-03-31 14:00:49 +0100 (Tue, 31 Mar 2009) $, $Revision: 2829 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -120,13 +120,14 @@ $SLANG = array(
     'Auto'                  => 'Auto',
     'AutoStopTimeout'       => 'Auto Stop Timeout',
     'AvgBrScore'            => 'Avg.<br/>Score',
+    'Available'             => 'Available',
     'Background'            => 'Background',
     'BackgroundFilter'      => 'Run filter in background',
     'BadAlarmFrameCount'    => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'        => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'            => 'Channel must be set to an integer of zero or more',
     'BadDevice'             => 'Device must be set to a valid value',
-    'BadFormat'             => 'Format must be set to an integer of zero or more',
+    'BadFormat'             => 'Format must be set to a valid value',
     'BadFPSReportInterval'  => 'FPS report interval buffer count must be an integer of 100 or more',
     'BadFrameSkip'          => 'Frame skip count must be an integer of zero or more',
     'BadHeight'             => 'Height must be set to a valid value',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'             => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'             => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'          => 'Names may only contain alphanumeric characters plus hyphen and underscore',
+    'BadPalette'            => 'Palette must be set to a valid value',
     'BadPath'               => 'Path must be set to a valid value',
     'BadPort'               => 'Port must be set to a valid number',
     'BadPostEventCount'     => 'Post event image count must be an integer of zero or more',
@@ -200,6 +202,7 @@ $SLANG = array(
     'Cause'                 => 'Cause',
     'Layout'                => 'Layout',
     'CheckMethod'           => 'Alarm Check Method',
+    'ChooseDetectedCamera'  => 'Choose Detected Camera',
     'ChooseFilter'          => 'Choose Filter',
     'ChoosePreset'          => 'Choose Preset',
     'Close'                 => 'Close',
@@ -234,6 +237,7 @@ $SLANG = array(
     'Delete'                => 'Delete',
     'DeleteSavedFilter'     => 'Delete saved filter',
     'Description'           => 'Description',
+    'DetectedCameras'       => 'Detected Cameras',
     'DeviceChannel'         => 'Device Channel',
     'DeviceFormat'          => 'Device Format',
     'DeviceNumber'          => 'Device Number',
@@ -253,6 +257,7 @@ $SLANG = array(
     'DonateRemindWeek'      => 'Not yet, remind again in 1 week',
     'DonateYes'             => 'Yes, I\'d like to donate now',
     'Download'              => 'Download',
+    'DuplicateMonitorName'  => 'Duplicate Monitor Name',
     'Duration'              => 'Duration',
     'Edit'                  => 'Edit',
     'Email'                 => 'Email',
@@ -432,8 +437,10 @@ $SLANG = array(
     'Misc'                  => 'Misc',
     'MonitorIds'            => 'Monitor&nbsp;Ids',
     'Monitor'               => 'Monitor',
-    'MonitorPresetIntro'    => 'Select an appropriate preset from the list below.<br/><br/>Please note that this may overwrite any values you already have configured for this monitor.<br/><br/>',
+    'MonitorPresetIntro'    => 'Select an appropriate preset from the list below.<br/><br/>Please note that this may overwrite any values you already have configured for the current monitor.<br/><br/>',
     'MonitorPreset'         => 'Monitor Preset',
+    'MonitorProbeIntro'     => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>',
+    'MonitorProbe'          => 'Monitor Probe',
     'Monitors'              => 'Monitors',
     'Montage'               => 'Montage',
     'Month'                 => 'Month',
@@ -453,6 +460,7 @@ $SLANG = array(
     'NewState'              => 'New State',
     'NewUser'               => 'New User',
     'Next'                  => 'Next',
+    'NoDetectedCameras'     => 'No Detected Cameras',
     'NoFramesRecorded'      => 'There are no frames recorded for this event',
     'NoGroup'               => 'No Group',
     'NoneAvailable'         => 'None available',
@@ -508,6 +516,7 @@ $SLANG = array(
     'Preset'                => 'Preset',
     'Presets'               => 'Presets',
     'Prev'                  => 'Prev',
+    'Probe'                 => 'Probe',
     'Protocol'              => 'Protocol',
     'Rate'                  => 'Rate',
     'Real'                  => 'Real',
