@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK French language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web UK French language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -119,6 +119,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Semaine',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Score<br/>moy.',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Les noms ne peuvent contenir que des lettres, chiffres, trait d\'union ou soulign',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -199,6 +201,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Larg. capture',
     'Cause'                => 'Cause',
     'CheckMethod'          => 'Mthode vrif. alarme',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Choisir filtre',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => 'Fermer',
@@ -233,6 +236,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Eff. &amp; prec.',
     'DeleteSavedFilter'    => 'Eff. filtre sauv',
     'Description'          => 'Description',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Canal camra',
     'DeviceFormat'         => 'Format camra',
@@ -252,6 +256,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Dure',
     'Edit'                 => 'Editer',
     'Email'                => 'Courriel',
@@ -434,6 +439,8 @@ $SLANG = array(
     'MonitorIds'           => 'N&nbsp;cran',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Ecrans',
     'Montage'              => 'Montage',
     'Month'                => 'Mois',
@@ -454,6 +461,7 @@ $SLANG = array(
     'NewUser'              => 'Nv util.',
     'Next'                 => 'Suiv.',
     'No'                   => 'Non',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Pas d\'image enregistre pour cet vnement',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'Pasfiltressauv',
@@ -508,6 +516,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Prec.',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Dbit',
     'Real'                 => 'Rel',
@@ -807,4 +816,3 @@ $OLANG = array(
 );
 
 ?>
-
