@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web IL Hebrew language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web IL Hebrew language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -119,6 +119,7 @@ $SLANG = array(
     'AttrWeekday'          => ' ',
     'Auto'                 => '',
     'AutoStopTimeout'      => '   ',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => '<br/>',
     'Background'           => '',
     'BackgroundFilter'     => '  ',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Names may only contain alphanumeric characters plus hyphen and underscore',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -199,6 +201,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Capture Width',
     'Cause'                => '',
     'CheckMethod'          => 'Alarm Check Method',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => ' ',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => '',
@@ -233,6 +236,7 @@ $SLANG = array(
     'DeleteAndPrev'        => ' &amp; ',
     'DeleteSavedFilter'    => '  ',
     'Description'          => '',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => ' ',
     'DeviceFormat'         => ' ',
@@ -252,6 +256,7 @@ $SLANG = array(
     'DonateRemindWeek'     => ' ,     ',
     'DonateYes'            => ',    ',
     'Download'             => '',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => ' ',
     'Edit'                 => '',
     'Email'                => '"',
@@ -434,6 +439,8 @@ $SLANG = array(
     'MonitorIds'           => 'Monitor&nbsp;Ids',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => '',
     'Montage'              => 'Montage',
     'Month'                => '',
@@ -454,6 +461,7 @@ $SLANG = array(
     'NewUser'              => ' ',
     'Next'                 => '',
     'No'                   => '',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'There are no frames recorded for this event',
     'NoGroup'              => ' ',
     'NoSavedFilters'       => 'NoSavedFilters',
@@ -508,6 +516,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => '',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => '',
     'Real'                 => '',
@@ -807,4 +816,3 @@ $OLANG = array(
 );
 
 ?>
-
