@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web HU Hungarian language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web HU Hungarian language file, $Date: 2009-06-29 10:52:48 +0100 (Mon, 29 Jun 2009) $, $Revision: 2934 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -19,6 +19,7 @@
 //
 
 // ZoneMinder Hungarian Translation by szimszon at oregpreshaz dot eu, robi
+// version: 0.6 - 2009.06.21. - frissts 1.24.2-hz (robi)
 // version: 0.5 - 2007.12.30. - frissts 1.23.1-hez (robi)
 // version: 0.4 - 2007.12.30. - frissts 1.23.0-hoz (robi)
 // version: 0.3 - 2006.04.27. - fordts befejezse, elrendezse elfrshez (robi)
@@ -82,7 +83,7 @@ $SLANG = array(
     '24BitColour'          => '24 bites szn',
     '8BitGrey'             => '8 bit szrkernyalat',
     'Action'               => 'Mvelet',
-    'Actual'               => 'Tnyleges',
+    'Actual'               => 'Vals',
     'AddNewControl'        => 'j vezrls',
     'AddNewMonitor'        => 'j monitor',
     'AddNewUser'           => 'j felhasznl',
@@ -104,7 +105,7 @@ $SLANG = array(
     'Archive'              => 'Archivls',
     'Archived'             => 'Archvum',
     'Area'                 => 'Terlet',
-    'AreaUnits'            => 'Terlet (px/%)',
+    'AreaUnits'            => 'Terlet (kppont / %)',
     'AttrAlarmFrames'      => 'Riad kpkockk',
     'AttrArchiveStatus'    => 'Archivlt llapot',
     'AttrAvgScore'         => 'tlagos rtk',
@@ -127,6 +128,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Htkznap',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto megllsi id tllps',
+    'Available'            => 'Elrhet',
     'AvgBrScore'           => 'tlag<br/>rtk',
     'Background'           => 'Httr',
     'BackgroundFilter'     => 'Szr futtatsa a httrben',
@@ -144,6 +146,7 @@ $SLANG = array(
     'BadLabelY'            => 'A cimke Y koordintja legyen 0 vagy nagyobb egsz szm',
     'BadMaxFPS'            => 'A maximlis FPS nullnl nagyobb szm legyen',
     'BadNameChars'         => 'A nv csak alfanumerikus karaktereket, plusz-, kt-, s alhzsjelet tartalmazhat',
+    'BadPalette'           => 'A palettnak egy helyes rtket kell megadni',
     'BadPath'              => 'A kp elrsi tvonala vals legyen',
     'BadPort'              => 'A portszm vals legyen',
     'BadPostEventCount'    => 'Az esemny utni kpek puffere 0 vagy nagyobb egsz szm legyen',
@@ -155,7 +158,7 @@ $SLANG = array(
     'BadWarmupCount'       => 'Bemelegt kpek szma 0 vagy nagyobb egsz szm legyen',
     'BadWebColour'         => 'A web szn rvnyes web szn kd legyen',
     'BadWidth'             => 'A kpszlessg rvnyes rtk legyen kppontban',
-    'Bandwidth'            => 'Svszlessgre',
+    'Bandwidth'            => 'svszlessgre',
     'BlobPx'               => 'Blob kppont',
     'BlobSizes'            => 'Blob mrete',
     'Blobs'                => 'Blob-ok',
@@ -202,11 +205,12 @@ $SLANG = array(
     'Cancel'               => 'Mgsem',
     'CancelForcedAlarm'    => 'Kzi riaszts lelltsa',
     'CaptureHeight'        => 'Kpmagassg',
-    'CaptureMethod'        => 'Capture Method',         // Added - 2009-02-08
-    'CapturePalette'       => 'Felvtel szn-paletta',
+    'CaptureMethod'        => 'Digitalizls mdszere',
+    'CapturePalette'       => 'Digitalizls szn-palettja',
     'CaptureWidth'         => 'Kpszlessg',
     'Cause'                => 'Okoz',
     'CheckMethod'          => 'A riaszts figyelsnek mdja',
+    'ChooseDetectedCamera' => 'Vlasszon rzkelt kamert',
     'ChooseFilter'         => 'Vlassz szrt',
     'ChoosePreset'         => 'Vlassz profilt',
     'Close'                => 'Bezr',
@@ -229,19 +233,20 @@ $SLANG = array(
     'ControlDevice'        => 'Vezrl eszkz',
     'ControlType'          => 'Vezrls tpusa',
     'Controllable'         => 'Vezrelhet',
-    'Cycle'                => 'Krkapcsols',
-    'CycleWatch'           => 'Krkapcsols',
+    'Cycle'                => 'Krbekapcsols',
+    'CycleWatch'           => 'Krbekapcsols',
     'Day'                  => 'Napon',
     'Debug'                => 'Nyomon<br>kvets',
-    'DefaultRate'          => 'Alaprtelmezett FPS',
-    'DefaultScale'         => 'Alaprtelmezett arny',
+    'DefaultRate'          => 'Alaprtelmezett sebessg',
+    'DefaultScale'         => 'Alaprtelmezett mret',
     'DefaultView'          => 'Alaprtelmezett nzet',
     'Delete'               => 'Trl',
     'DeleteAndNext'        => 'Trl &amp;<br>kvetkez',
     'DeleteAndPrev'        => 'Trl &amp;<br>elz',
     'DeleteSavedFilter'    => 'Mentett szr trlse',
     'Description'          => 'Lers',
-    'Device'               => 'Device',                 // Added - 2009-02-08
+    'DetectedCameras'      => 'rzkelt kamerk',
+    'Device'               => 'Eszkz',
     'DeviceChannel'        => 'Eszkz csatornja',
     'DeviceFormat'         => 'Eszkz formtuma',
     'DeviceNumber'         => 'Eszkz szm',
@@ -260,6 +265,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Nem most, figyelmeztess 1 ht mlva',
     'DonateYes'            => 'Igen, most szeretnm tmogatni',
     'Download'             => 'Letlt',
+    'DuplicateMonitorName' => 'Monitor nevnek dupliklsa',
     'Duration'             => 'Idtartam',
     'Edit'                 => 'Szerkeszt',
     'Email'                => 'Email',
@@ -288,16 +294,16 @@ $SLANG = array(
     'ExportImageFiles'     => 'Kpek exportlsa',
     'ExportMiscFiles'      => 'Egyb fjlok exportlsa (ha vannak)',
     'ExportOptions'        => 'Exportls belltsai',
-    'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
+    'ExportSucceeded'      => 'Az exportls sikerlt',
     'ExportVideoFiles'     => 'Vide fjlok exportlsa (ha vannak)',
     'Exporting'            => 'Exportls...',
     'FPS'                  => 'fps',
-    'FPSReportInterval'    => 'FPS jelents idkze',
+    'FPSReportInterval'    => 'FPS megjelents idkze',
     'FTP'                  => 'FTP',
     'Far'                  => 'Tvol',
     'FastForward'          => 'Elre tekers',
     'Feed'                 => 'Folyam',
-    'Ffmpeg'               => 'Ffmpeg',                 // Added - 2009-02-08
+    'Ffmpeg'               => 'Ffmpeg',
     'File'                 => 'Fjl',
     'FilterArchiveEvents'  => 'Minden tallat archivlsa',
     'FilterDeleteEvents'   => 'Minden tallat trlse',
@@ -318,7 +324,7 @@ $SLANG = array(
     'Frame'                => 'Kpkocka',
     'FrameId'              => 'Kpkocka azonost',
     'FrameRate'            => 'FPS',
-    'FrameSkip'            => 'Kpk. kihagys',
+    'FrameSkip'            => 'Kpkocka kihagys',
     'Frames'               => 'Kpkocka',
     'Func'                 => 'Funk.',
     'Function'             => 'Funkci',
@@ -360,7 +366,7 @@ $SLANG = array(
     'Label'                => 'Cimke',
     'Language'             => 'Nyelv',
     'Last'                 => 'Utols',
-    'Layout'               => 'Layout',                 // Added - 2009-02-08
+    'Layout'               => 'Elrendezs',
     'LimitResultsPost'     => 'tallatig korltoz', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Az els', // This is used at the beginning of the phrase 'Limit to first N results only'
     'LinkedMonitors'       => 'sszefgg monitorok',
@@ -426,8 +432,8 @@ $SLANG = array(
     'MinPanRange'          => 'Min. jobb-bal tartomny',
     'MinPanSpeed'          => 'Min. jobb-bal sebessg',
     'MinPanStep'           => 'Min. jobb-bal lps',
-    'MinPixelThresLtMax'   => 'A minimum kszb kppontnak kisebbnek kell lennie, mint a maximum',
-    'MinPixelThresUnset'   => 'Meg kell adnod a minimum kppont kszbt',
+    'MinPixelThresLtMax'   => 'A kppont minimum eltrsi kszbnek kisebbnek kell lennie, mint a maximum',
+    'MinPixelThresUnset'   => 'Meg kell adnod a kppont minimum eltrsi kszbt',
     'MinTiltRange'         => 'Min. fel-le tartomny',
     'MinTiltSpeed'         => 'Min. fel-le sebessg',
     'MinTiltStep'          => 'Min. fel-le lps',
@@ -439,10 +445,12 @@ $SLANG = array(
     'MinZoomStep'          => 'Min. zoom lps',
     'Misc'                 => 'Egyb',
     'Monitor'              => 'Monitor',
-    'MonitorIds'           => 'Monitor&nbsp;Azonostk',
-    'MonitorPreset'        => 'Elre belltott rtkprofilok megfigyelshez',
+    'MonitorIds'           => 'Monitor&nbsp;azonostk',
+    'MonitorPreset'        => 'Elre belltott monitorprofilok',
     'MonitorPresetIntro'   => 'Vlassz egy, az elre meghatrozott<br> rtkprofilt az albbiak kzl.<br><br>Vedd figyelembe, hogy ez fellrhatja <br>az ltalad mr belltott rtkeket.<br><br>',
-    'Monitors'             => 'Megfigyelsek',
+    'MonitorProbe'         => 'Monitor szlels',
+    'MonitorProbeIntro'    => 'Az albbi listban tallhatk az automatikusan rzkelt analg s hlzati kamerkat, illetve azt, hogy kzlk melyik van hasznlatban, vagy kivlaszthat.<br/><br/>Vlasszon egyet az albbi listbl.<br/><br/>Figyelem! Nem biztos, hogy minden kamert lehet automatikusan rzkelni. Az itt kivlasztott kamara adatai fellrhatjk azokat, amelyeket mr ehhez a monitorhoz belltott.<br/><br/>',
+    'Monitors'             => 'Monitorok',
     'Montage'              => 'Tbbkamers nzet',
     'Month'                => 'Hnapban',
     'Move'                 => 'Mozgs',
@@ -458,17 +466,18 @@ $SLANG = array(
     'NewGroup'             => 'j csoport',
     'NewLabel'             => 'j cimke',
     'NewPassword'          => 'j jelsz',
-    'NewState'             => 'j llapot',
+    'NewState'             => 'j llapot neve',
     'NewUser'              => 'j felhasznl',
     'Next'                 => 'Kvetkez',
     'No'                   => 'Nem',
+    'NoDetectedCameras'    => 'Nincsenek rzkelt kamerk',
     'NoFramesRecorded'     => 'Nincs felvett kpkocka ehhez az esemnyhez',
     'NoGroup'              => 'Nincs csoport',
     'NoSavedFilters'       => 'Nincs mentett szr',
     'NoStatisticsRecorded' => 'Nincs mentett statisztika ehhez az esemnyhez/kpkockhoz',
     'None'                 => 'Nincs kivlasztva',
-    'NoneAvailable'        => 'Nincs elrhet',
-    'Normal'               => 'Normlis',
+    'NoneAvailable'        => 'Nem elrhet',
+    'Normal'               => 'Norml',
     'Notes'                => 'Megjegyzsek',
     'NumPresets'           => 'Profilok szma',
     'Off'                  => 'Ki',
@@ -516,6 +525,7 @@ $SLANG = array(
     'Preset'               => 'Elre belltott profil',
     'Presets'              => 'Elre belltott profilok',
     'Prev'                 => 'Elz',
+    'Probe'                => 'rzkels',
     'Protocol'             => 'Protocol',
     'Rate'                 => 'FPS',
     'Real'                 => 'Vals',
@@ -524,20 +534,20 @@ $SLANG = array(
     'Refresh'              => 'Frisst',
     'Remote'               => 'Hlzati',
     'RemoteHostName'       => 'Hlzati IP cm/hosztnv',
-    'RemoteHostPath'       => 'A kp elrsi tja',
-    'RemoteHostPort'       => 'Hlzati gp portszma',
-    'RemoteHostSubPath'    => 'Remote Host SubPath',    // Added - 2009-02-08
+    'RemoteHostPath'       => 'A kp elrsi tvonala',
+    'RemoteHostPort'       => 'Hlzati portszm',
+    'RemoteHostSubPath'    => 'A kp elrsi al-tvonala',
     'RemoteImageColours'   => 'A kp szne',
-    'RemoteMethod'         => 'Remote Method',          // Added - 2009-02-08
-    'RemoteProtocol'       => 'Remote Protocol',        // Added - 2009-02-08
-    'Rename'               => 'tnevez',
+    'RemoteMethod'         => 'Hlzati metdus',
+    'RemoteProtocol'       => 'Hlzati protokoll',
+    'Rename'               => 'tnevezs',
     'Replay'               => 'Visszajtszs',
     'ReplayAll'            => 'Minden esemnyt',
     'ReplayGapless'        => 'Folyamatos esemnyeket',
     'ReplaySingle'         => 'Egyni esemny',
     'Reset'                => 'Alaprtkre llt',
     'ResetEventCounts'     => 'Esemny szmll nullzsa',
-    'Restart'              => 'jraindt',
+    'Restart'              => 'A szolgltats jraindtsa',
     'Restarting'           => 'jraindts',
     'RestrictedCameraIds'  => 'Korltozott kamerk azonosti',
     'RestrictedMonitors'   => 'Korltozott kamerk',
@@ -547,7 +557,7 @@ $SLANG = array(
     'RotateLeft'           => 'Balra forgats',
     'RotateRight'          => 'Jobbra forgats',
     'RunMode'              => 'Futsi md',
-    'RunState'             => 'Futsi llapot',
+    'RunState'             => 'A ZoneMinder llapota',
     'Running'              => 'les',
     'Save'                 => 'Ments',
     'SaveAs'               => 'Ments mint',
@@ -572,9 +582,9 @@ $SLANG = array(
     'SortBy'               => 'Sorbarendezs:',
     'SortDesc'             => 'Cskken',
     'Source'               => 'Forrs',
-    'SourceColours'        => 'Source Colours',         // Added - 2009-02-08
-    'SourcePath'           => 'Source Path',            // Added - 2009-02-08
-    'SourceType'           => 'Forrs tpusa',
+    'SourceColours'        => 'A kp szne',
+    'SourcePath'           => 'A kp elrsi tvonala',
+    'SourceType'           => 'Kp-forrs tpusa',
     'Speed'                => 'Sebessg',
     'SpeedHigh'            => 'Nagy sebssg',
     'SpeedLow'             => 'Alacsony sebessg',
@@ -592,8 +602,8 @@ $SLANG = array(
     'StepNone'             => 'Nincs ugrs',
     'StepSmall'            => 'Kis ugrs',
     'Stills'               => 'llkpek',
-    'Stop'                 => 'Megllts',
-    'Stopped'              => 'Meglltva',
+    'Stop'                 => 'A szolgltats lelltsa',
+    'Stopped'              => 'Lelltva',
     'Stream'               => 'l folyam',
     'StreamReplayBuffer'   => 'Folyam visszajtsz kppuffer',
     'Submit'               => 'Elkld',
@@ -619,8 +629,8 @@ $SLANG = array(
     'TurboTiltSpeed'       => 'Turbo fel-le sebessg',
     'Type'                 => 'Tpus',
     'Unarchive'            => 'Archvumbl ki',
-    'Undefined'            => 'Undefined',              // Added - 2009-02-08
-    'Units'                => 'Egysgek',
+    'Undefined'            => 'Nincs megadva',
+    'Units'                => 'Egysg',
     'Unknown'              => 'Ismeretlen',
     'Update'               => 'Frissts',
     'UpdateAvailable'      => 'Elrhet ZoneMinder frissts.',
@@ -668,15 +678,15 @@ $SLANG = array(
     'Yes'                  => 'Igen',
     'YouNoPerms'           => 'Nincs jogod az erforrs elrshez.',
     'Zone'                 => 'Zna:',
-    'ZoneAlarmColour'      => 'Riad szn (R/G/B)',
-    'ZoneArea'             => 'Zna terlet',
-    'ZoneFilterSize'       => 'Szrt szlessg/magassg (kppontok)',
+    'ZoneAlarmColour'      => 'Riad sznezs (R/G/B)',
+    'ZoneArea'             => 'Zna lefedettsge',
+    'ZoneFilterSize'       => 'Szrt szlessg/magassg<br>(kppont)',
     'ZoneMinMaxAlarmArea'  => 'Min/Max riad terlet',
     'ZoneMinMaxBlobArea'   => 'Min/Max Blob terlet',
     'ZoneMinMaxBlobs'      => 'Min/Max Blobok',
     'ZoneMinMaxFiltArea'   => 'Min/Max szrt terlet',
-    'ZoneMinMaxPixelThres' => 'Min/Max kppont kszb (0-255)',
-    'ZoneOverloadFrames'   => 'Tlterhels esetn ennyi kpkocka hagyhat ki',
+    'ZoneMinMaxPixelThres' => 'Min/Max kppont eltrsi<br>kszb (0-255)',
+    'ZoneOverloadFrames'   => 'Tlterhels esetn<br>ennyi kpkocka hagyhat ki',
     'Zones'                => 'Znk',
     'Zoom'                 => 'Zoom',
     'ZoomIn'               => 'Zoom be',
@@ -728,8 +738,8 @@ $CLANG = array(
 
 // Variable arrays expressing plurality, see the zmVlang description above
 $VLANG = array(
-    'Event'                => array( 0=>'Esemnyek', 1=>'Esemny', 2=>'Esemny' ),
-    'Monitor'              => array( 0=>'Monitorok', 1=>'Monitor', 2=>'Monitor' ),
+    'Event'                => array( 0=>'Esemny', 1=>'Esemny', 2=>'Esemny' ),
+    'Monitor'              => array( 0=>'Monitor', 1=>'Monitor', 2=>'Monitor' ),
 );
 
 // You will need to choose or write a function that can correlate the plurality string arrays
@@ -815,5 +825,3 @@ $OLANG = array(
 );
 
 ?>
-
-
