@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Italian language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -124,6 +124,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Giorno della settimana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Punteggio<br/>medio',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Esegui filtro in background',
@@ -141,6 +142,7 @@ $SLANG = array(
     'BadLabelY'            => 'L\'etichetta della coordinata Y deve essere un numero intero pari a 0 o maggiore',
     'BadMaxFPS'            => 'I frame per secondo (FPS) massimi devono essere un numero intero positivo o un valore in virgola mobile',
     'BadNameChars'         => 'I nomi possono contenere solo caratteri alfanumerici pi&ugrave; i caratteri - e _',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Il percorso deve essere impostato con un valore valido',
     'BadPort'              => 'La porta deve essere settata con un valore valido',
     'BadPostEventCount'    => 'Il buffer d\'immagine successivo ad un evento deve essere un numero maggiore o uguale a zero',
@@ -204,6 +206,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Larghezza img Catturata',
     'Cause'                => 'Causa',
     'CheckMethod'          => 'Metodo di Controllo Allarme',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Scegli Filtro',
     'ChoosePreset'         => 'Scegli Preset',
     'Close'                => 'Chiudi',
@@ -238,6 +241,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Elimina &amp; Precedente',
     'DeleteSavedFilter'    => 'Elimina il filtro salvato',
     'Description'          => 'Descrizione',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Canale Periferica',
     'DeviceFormat'         => 'Formato',
@@ -257,6 +261,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Non ancora, ricordamelo ancora tra 1 settimana',
     'DonateYes'            => 'Si,mi piacerebbe donare qualcosa ora',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Durata',
     'Edit'                 => 'Modifica',
     'Email'                => 'Email',
@@ -439,6 +444,8 @@ $SLANG = array(
     'MonitorIds'           => 'Monitor&nbsp;Ids',
     'MonitorPreset'        => 'Monitor Presenti',
     'MonitorPresetIntro'   => 'Selezionare un appropriato pre settaggio dalla lista riportata qui sotto.<br><br>Per favore notare che questo potrebbe sovrascrivere ogni valore che hai già configurato su questo monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitors',
     'Montage'              => 'Montaggio',
     'Month'                => 'Mese',
@@ -459,6 +466,7 @@ $SLANG = array(
     'NewUser'              => 'Nuovo Utente',
     'Next'                 => 'Prossimo',
     'No'                   => 'No',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Non ci sono immagini salvate per questo evento',
     'NoGroup'              => 'No Group',               // Added - 2009-02-08
     'NoSavedFilters'       => 'NessunFiltroSalvato',
@@ -513,6 +521,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Prec',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Velocita\'',
     'Real'                 => 'Reale',
@@ -812,4 +821,3 @@ $OLANG = array(
 );
 
 ?>
-
