@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Polish language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Polish language file, $Date: 2009-05-13 11:58:00 +0100 (Wed, 13 May 2009) $, $Revision: 2872 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -119,6 +119,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Dzie roboczy',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'red.<br/>wynik',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -136,6 +137,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Nazwy mog zawiera tylko litery, cyfry oraz mylnik i podkrelenie',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -199,6 +201,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Szeroko obrazu',
     'Cause'                => 'Cause',
     'CheckMethod'          => 'Metoda sprawdzenia alarmu',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Wybierz filtr',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => 'Zamknij',
@@ -233,6 +236,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Usu &amp; poprzedni',
     'DeleteSavedFilter'    => 'Usu zapisany filtr',
     'Description'          => 'Opis',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Numer wejcia w urzdzeniu',
     'DeviceFormat'         => 'System TV',
@@ -252,6 +256,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Czas trwania',
     'Edit'                 => 'Edycja',
     'Email'                => 'Email',
@@ -434,6 +439,8 @@ $SLANG = array(
     'MonitorIds'           => 'Numery&nbsp;monitorw',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitory',
     'Montage'              => 'Monta',
     'Month'                => 'Miesic',
@@ -454,6 +461,7 @@ $SLANG = array(
     'NewUser'              => 'nowy',
     'Next'                 => 'Nastpny',
     'No'                   => 'Nie',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Brak zapisanych ramek dla tego zdarzenia',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'BrakZapisanychFiltrw',
@@ -508,6 +516,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Poprzedni',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Tempo',
     'Real'                 => 'Rzeczywiste',
@@ -786,4 +795,3 @@ $OLANG = array(
 );
 
 ?>
-
