@@ -59,6 +59,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Dia/Semana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Maior<br/>Score',
     'Background'           => 'Background',
     'BackgroundFilter'     => 'Run filter in background',
@@ -76,6 +77,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'         => 'Nomes devem ser caracteres alfanumricos mais hfen e underscore',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
     'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
@@ -139,6 +141,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Largura de Captura',
     'Cause'                => 'Cause',
     'CheckMethod'          => 'Metodo marcar por alarme',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Escolher Filtro',
     'ChoosePreset'         => 'Choose Preset',
     'Close'                => 'Fechar',
@@ -173,6 +176,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Deletar &amp; Ant',
     'DeleteSavedFilter'    => 'Deletar Filtros Salvos',
     'Description'          => 'Descrio',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Canal do Dispositivo',
     'DeviceFormat'         => 'Formato do Dispos.',
@@ -192,6 +196,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Durao',
     'Edit'                 => 'Editar',
     'Email'                => 'Email',
@@ -374,6 +379,8 @@ $SLANG = array(
     'MonitorIds'           => 'Ids&nbsp;de Monitor',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitores',
     'Montage'              => 'Montagem',
     'Month'                => 'Ms',
@@ -394,6 +401,7 @@ $SLANG = array(
     'NewUser'              => 'Novo Usurio',
     'Next'                 => 'Prx',
     'No'                   => 'No',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'No h imagens gravadas neste evento',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'SemFiltrosSalvos',
@@ -448,6 +456,7 @@ $SLANG = array(
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
     'Prev'                 => 'Ant.',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
     'Rate'                 => 'Vel.',
     'Real'                 => 'Real',
@@ -747,4 +756,3 @@ $OLANG = array(
 );
 
 ?>
-
