@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Swedish language file, $Date: 2009-02-08 17:39:12 +0000 (Sun, 08 Feb 2009) $, $Revision: 2746 $
+// ZoneMinder web Swedish language file, $Date: 2009-05-24 11:00:20 +0100 (Sun, 24 May 2009) $, $Revision: 2889 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -120,6 +120,7 @@ $SLANG = array(
     'AttrWeekday'          => 'Veckodag',
     'Auto'                 => 'Automatik',
     'AutoStopTimeout'      => 'Tidsutlsning fr automatstop',
+    'Available'            => 'Available',              // Added - 2009-03-31
     'AvgBrScore'           => 'Ung.<br/>trff',
     'Background'           => 'Bakgrund',
     'BackgroundFilter'     => 'Kr filter i bakgrunden',
@@ -137,6 +138,7 @@ $SLANG = array(
     'BadLabelY'            => 'Etiketten fr Y koordinaten mste sttas till ett heltal, 0 eller hgre',
     'BadMaxFPS'            => 'Max. ramar/s mste vara ett positivt heltal eller ett flyttal',
     'BadNameChars'         => 'Namn kan endast innehlla alfanumeriska tecken, bindestreck och understreck',
+    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Skvgen mste innehlla ett giltigt vrde',
     'BadPort'              => 'Porten mste innehlla ett giltigt nummer',
     'BadPostEventCount'    => 'Rknaren fr efterhndelsen mste vara ett heltal p 0 eller hgre',
@@ -200,6 +202,7 @@ $SLANG = array(
     'CaptureWidth'         => 'Fngstbredd',
     'Cause'                => 'Orsak',
     'CheckMethod'          => 'Larmkontrollmetod',
+    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Vlj filter',
     'ChoosePreset'         => 'Vlj standard',
     'Close'                => 'Stng',
@@ -234,6 +237,7 @@ $SLANG = array(
     'DeleteAndPrev'        => 'Radera &amp; Freg.',
     'DeleteSavedFilter'    => 'Radera sparade filter',
     'Description'          => 'Beskrivning',
+    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
     'DeviceChannel'        => 'Enhetskanal',
     'DeviceFormat'         => 'Enhetsformat',
@@ -253,6 +257,7 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Inte n, pminn om 1 vecka',
     'DonateYes'            => 'Ja, jag vill grna donera nu',
     'Download'             => 'Ladda ner',
+    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Lngd',
     'Edit'                 => 'Redigera',
     'Email'                => 'E-post',
@@ -435,6 +440,8 @@ $SLANG = array(
     'MonitorIds'           => 'Bevakningsnr',
     'MonitorPreset'        => 'Frinstlld bevakning',
     'MonitorPresetIntro'   => 'Vlj en frinstllning frn listan.<br><br>Var medveten om att detta kan skriva ver instllningar du redan gjort fr denna bevakare.<br><br>',
+    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Bevakare',
     'Montage'              => 'Montera',
     'Month'                => 'Mnad',
@@ -455,6 +462,7 @@ $SLANG = array(
     'NewUser'              => 'Ny anvndare',
     'Next'                 => 'Nsta',
     'No'                   => 'Nej',
+    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
     'NoFramesRecorded'     => 'Det finns inga ramar inspelade fr denna hndelse',
     'NoGroup'              => 'Ingen grupp',
     'NoSavedFilters'       => 'Inga sparade filter',
@@ -509,6 +517,7 @@ $SLANG = array(
     'Preset'               => 'Frinstllning',
     'Presets'              => 'Frinstllningar',
     'Prev'                 => 'Freg.',
+    'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protokol',
     'Rate'                 => 'Hastighet',
     'Real'                 => 'Verklig',
@@ -807,4 +816,3 @@ $OLANG = array(
 );
 
 ?>
-
