@@ -187,7 +187,7 @@ function applyCheckMethod()
 function applyPreset()
 {
     var form = document.zoneForm;
-    var presetId = $('presetSelector').getValue();
+    var presetId = $('presetSelector').get('value');
 
     if ( presets[presetId] )
     {
@@ -317,20 +317,16 @@ function unsetActivePoint( index )
     $('point'+index).removeClass( 'active' );
 }
 
-function updateZoneImageResponse( respText )
+function updateZoneImageResponse( respObj, respText )
 {
-    if ( respText == 'Ok' )
-        return;
-    var response = Json.evaluate( respText );
-
-    if ( response.result == 'Ok' )
+    if ( respObj.result == 'Ok' )
     {
-        document.zoneForm.elements['submitBtn'].disabled = ( selfIntersecting = response.selfIntersecting );
-        document.zoneForm.elements['newZone[Area]'].value = zone.Area = response.area;
+        document.zoneForm.elements['submitBtn'].disabled = ( selfIntersecting = respObj.selfIntersecting );
+        document.zoneForm.elements['newZone[Area]'].value = zone.Area = respObj.area;
         if ( document.zoneForm.elements['newZone[Units]'].value == 'Pixels' )
             document.zoneForm.elements['newZone[TempArea]'].value = document.zoneForm.elements['newZone[Area]'].value;
         
-        var newImage = new Asset.image( response.zoneImage, { 'onload': function() { $('zoneImage').src = newImage.src; } } );
+        var newImage = new Asset.image( respObj.zoneImage, { 'onload': function() { $('zoneImage').src = newImage.src; } } );
     }
 }
 
@@ -345,8 +341,8 @@ function getCoordString()
 function updateZoneImage()
 {
     var parms = "view=request&request=zone&action=zoneImage&mid="+zone.MonitorId+"&zid="+zone.Id+"&coords="+getCoordString();
-    var query = new Ajax( thisUrl, { method: 'post', timeout: AJAX_TIMEOUT, data: parms, onComplete: updateZoneImageResponse } );
-    query.request();
+    var query = new Request.JSON( { url: thisUrl, method: 'post', timeout: AJAX_TIMEOUT, data: parms, onComplete: updateZoneImageResponse } );
+    query.send();
 }
 
 function fixActivePoint( index )
@@ -402,7 +398,7 @@ function updateX( index )
     limitPointValue( $('newZone[Points]['+index+'][x]'), 0, maxX );
 
     var point = $('point'+index);
-    var x = $('newZone[Points]['+index+'][x]').getValue();
+    var x = $('newZone[Points]['+index+'][x]').get('value');
 
     point.setStyle( 'left', x+'px' );
     zone['Points'][index].x = x;
@@ -415,7 +411,7 @@ function updateY( index )
     limitPointValue( $('newZone[Points]['+index+'][y]'), 0, maxY );
 
     var point = $('point'+index);
-    var y = $('newZone[Points]['+index+'][y]').getValue();
+    var y = $('newZone[Points]['+index+'][y]').get('value');
 
     point.setStyle( 'top', y+'px' );
     zone['Points'][index].y = y;
@@ -436,7 +432,7 @@ function saveChanges( element )
 
 function drawZonePoints()
 {
-    $('imageFrame').getElements( 'div.zonePoint' ).each( function( element ) { element.remove(); } );
+    $('imageFrame').getElements( 'div.zonePoint' ).each( function( element ) { element.destroy(); } );
     for ( var i = 0; i < zone['Points'].length; i++ )
     {
         var div = new Element( 'div', { 'id': 'point'+i, 'class': 'zonePoint', 'title': 'Point '+(i+1), 'styles': { 'left': zone['Points'][i].x, 'top': zone['Points'][i].y } } );
@@ -453,7 +449,7 @@ function drawZonePoints()
         var row = new Element( 'tr', { 'id': 'row'+i } );
         row.addEvents( { 'mouseover': highlightOn.pass( i ), 'mouseout': highlightOff.pass( i ) } );
         var cell = new Element( 'td' );
-        cell.setText( i+1 );
+        cell.set( 'text', i+1 );
         cell.injectInside( row );
 
         cell = new Element( 'td' );
@@ -469,9 +465,9 @@ function drawZonePoints()
         cell.injectInside( row );
 
         cell = new Element( 'td' );
-        new Element( 'a', { 'href': '#', 'events': { 'click': addPoint.pass( i ) } } ).setText( '+' ).injectInside( cell );
+        new Element( 'a', { 'href': '#', 'events': { 'click': addPoint.pass( i ) } } ).set( 'text', '+' ).injectInside( cell );
         if ( zone['Points'].length > 3 )
-            new Element( 'a', { 'id': 'delete'+i, 'href': '#', 'events': { 'click': delPoint.pass( i ) } } ).setText( '-' ).injectInside( cell );
+            new Element( 'a', { 'id': 'delete'+i, 'href': '#', 'events': { 'click': delPoint.pass( i ) } } ).set( 'text', '-' ).injectInside( cell );
         cell.injectInside( row );
 
         row.injectInside( tables[i%tables.length].getElement( 'tbody' ) );
