@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web monitor view file, $Date: 2009-02-12 22:44:11 +0000 (Thu, 12 Feb 2009) $, $Revision: 2758 $
+// ZoneMinder web monitor view file, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -48,21 +48,21 @@ if ( !empty($_REQUEST['mid']) )
 }
 else
 {
+    $nextId = getTableAutoInc( 'Monitors' );
     $monitor = array(
         'Id' => 0,
-        'Name' => $SLANG['New'],
+        'Name' => $SLANG['Monitor'].'-'.$nextId,
         'Function' => "Monitor",
         'Enabled' => true,
         'LinkedMonitors' => "",
         'Type' => "Local",
         'Device' => "/dev/video",
         'Channel' => "0",
-        'Format' => "0",
+        'Format' => "",
         'Protocol' => "",
         'Method' => "",
         'Host' => "",
         'Path' => "",
-        'SubPath' => "",
         'Port' => "80",
         'Palette' => "",
         'Width' => "",
@@ -112,6 +112,11 @@ if ( ZM_OPT_X10 && empty($x10Monitor) )
     );
 }
 
+function fourcc( $a, $b, $c, $d )
+{
+    return( ord($a) | (ord($b) << 8) | (ord($c) << 16) | (ord($d) << 24) );
+}
+
 if ( isset( $_REQUEST['newMonitor'] ) )
 {
     $newMonitor = $_REQUEST['newMonitor'];
@@ -133,7 +138,7 @@ if ( $newMonitor['AlarmMaxFPS'] == '0.00' )
 
 if ( !empty($_REQUEST['preset']) )
 {
-    $preset = dbFetchOne( "select Type, Device, Channel, Format, Protocol, Method, Host, Port, Path, SubPath, Width, Height, Palette, MaxFPS, Controllable, ControlId, ControlDevice, ControlAddress, DefaultRate, DefaultScale from MonitorPresets where Id = '".dbEscape($_REQUEST['preset'])."'" );
+    $preset = dbFetchOne( "select Type, Device, Channel, Format, Protocol, Method, Host, Port, Path, Width, Height, Palette, MaxFPS, Controllable, ControlId, ControlDevice, ControlAddress, DefaultRate, DefaultScale from MonitorPresets where Id = '".dbEscape($_REQUEST['preset'])."'" );
     foreach ( $preset as $name=>$value )
     {
         if ( isset($value) )
@@ -142,6 +147,27 @@ if ( !empty($_REQUEST['preset']) )
         }
     }
 }
+if ( !empty($_REQUEST['probe']) )
+{
+    $probe = unserialize( $_REQUEST['probe'] );
+    foreach ( $probe as $name=>$value )
+    {
+        if ( isset($value) )
+        {
+            $newMonitor[$name] = $value;
+        }
+    }
+    if ( $newMonitor['Type'] == 'Local' )
+    {
+        $newMonitor['Palette'] = fourCC( substr($newMonitor['Palette'],0,1), substr($newMonitor['Palette'],1,1), substr($newMonitor['Palette'],2,1), substr($newMonitor['Palette'],3,1) );
+        if ( $newMonitor['Format'] == 'PAL' )
+            $newMonitor['Format'] = 0x000000ff;
+        elseif ( $newMonitor['Format'] == 'NTSC' )
+            $newMonitor['Format'] = 0x0000b000;
+        else
+            $newMonitor['Format'] = '';
+    }
+}
 
 $sourceTypes = array(
     'Local'  => $SLANG['Local'],
@@ -180,7 +206,7 @@ if ( !ZM_PCRE )
 unset($httpMethods['jpegTags']);
 
 $v4l1DeviceFormats = array(
-    $SLANG['Undefined'] => -1,
+    $SLANG['Undefined'] => '',
     "PAL"   => 0,
     "NTSC"  => 1,
     "SECAM" => 2,
@@ -197,7 +223,7 @@ for ( $i = 0; $i <= $v4l1MaxChannels; $i++ )
     $v4l1DeviceChannels["$i"] = $i;
 
 $v4l1LocalPalettes = array(
-    $SLANG['Undefined'] => 0,
+    $SLANG['Undefined'] => '',
     $SLANG['Grey']      => 1,
     "RGB24"             => 4,
     "RGB565"            => 3,
@@ -211,7 +237,9 @@ $v4l1LocalPalettes = array(
 if ( ZM_V4L2 )
 {
     $v4l2DeviceFormats = array(
-        $SLANG['Undefined'] => 0,
+        $SLANG['Undefined'] => '',
+        "PAL"         => 0x000000ff,
+        "NTSC"        => 0x0000b000,
         "PAL B"       => 0x00000001,
         "PAL B1"      => 0x00000002,
         "PAL G"       => 0x00000004,
@@ -245,13 +273,8 @@ if ( ZM_V4L2 )
     for ( $i = 0; $i <= $v4l2MaxChannels; $i++ )
         $v4l2DeviceChannels["$i"] = $i;
 
-    function fourcc( $a, $b, $c, $d )
-    {
-        return( ord($a) | (ord($b) << 8) | (ord($c) << 16) | (ord($d) << 24) );
-    }
-
     $v4l2LocalPalettes = array(
-        $SLANG['Undefined'] => 0,
+        $SLANG['Undefined'] => '',
 
         /*      Pixel format         FOURCC                        depth  Description  */
         //"RGB332" =>   fourcc('R','G','B','1'), /*  8  RGB-3-3-2     */
@@ -341,6 +364,7 @@ if ( canEdit( 'Monitors' ) )
 {
 ?>
       <div id="headerButtons">
+        <a href="#" onclick="createPopup( '?view=monitorprobe&mid=<?= $monitor['Id'] ?>', 'zmMonitorProbe<?= $monitor['Id'] ?>', 'monitorprobe' ); return( false );"><?= $SLANG['Probe'] ?></a>
         <a href="#" onclick="createPopup( '?view=monitorpreset&mid=<?= $monitor['Id'] ?>', 'zmMonitorPreset<?= $monitor['Id'] ?>', 'monitorpreset' ); return( false );"><?= $SLANG['Presets'] ?></a>
       </div>
 <?php
@@ -404,7 +428,6 @@ if ( $tab != 'source' || $newMonitor['Type'] != 'Local' )
     <input type="hidden" name="newMonitor[Device]" value="<?= validHtmlStr($newMonitor['Device']) ?>"/>
     <input type="hidden" name="newMonitor[Channel]" value="<?= validHtmlStr($newMonitor['Channel']) ?>"/>
     <input type="hidden" name="newMonitor[Format]" value="<?= validHtmlStr($newMonitor['Format']) ?>"/>
-    <input type="hidden" name="newMonitor[Palette]" value="<?= validHtmlStr($newMonitor['Palette']) ?>"/>
 <?php
 }
 if ( $tab != 'source' || $newMonitor['Type'] != 'Remote' )
@@ -413,7 +436,6 @@ if ( $tab != 'source' || $newMonitor['Type'] != 'Remote' )
     <input type="hidden" name="newMonitor[Protocol]" value="<?= validHtmlStr($newMonitor['Protocol']) ?>"/>
     <input type="hidden" name="newMonitor[Host]" value="<?= validHtmlStr($newMonitor['Host']) ?>"/>
     <input type="hidden" name="newMonitor[Port]" value="<?= validHtmlStr($newMonitor['Port']) ?>"/>
-    <input type="hidden" name="newMonitor[SubPath]" value="<?= validHtmlStr($newMonitor['SubPath']) ?>"/>
 <?php
 }
 if ( $tab != 'source' || ($newMonitor['Type'] != 'Local' && $newMonitor['Type'] != 'Remote') )
@@ -431,6 +453,7 @@ if ( $tab != 'source' || ($newMonitor['Type'] != 'Remote' && $newMonitor['Type']
 if ( $tab != 'source' )
 {
 ?>
+    <input type="hidden" name="newMonitor[Palette]" value="<?= validHtmlStr($newMonitor['Palette']) ?>"/>
     <input type="hidden" name="newMonitor[Width]" value="<?= validHtmlStr($newMonitor['Width']) ?>"/>
     <input type="hidden" name="newMonitor[Height]" value="<?= validHtmlStr($newMonitor['Height']) ?>"/>
     <input type="hidden" name="newMonitor[Orientation]" value="<?= validHtmlStr($newMonitor['Orientation']) ?>"/>
@@ -626,7 +649,6 @@ switch ( $tab )
             <tr><td><?= $SLANG['RemoteHostName'] ?></td><td><input type="text" name="newMonitor[Host]" value="<?= validHtmlStr($newMonitor['Host']) ?>" size="36"/></td></tr>
             <tr><td><?= $SLANG['RemoteHostPort'] ?></td><td><input type="text" name="newMonitor[Port]" value="<?= validHtmlStr($newMonitor['Port']) ?>" size="6"/></td></tr>
             <tr><td><?= $SLANG['RemoteHostPath'] ?></td><td><input type="text" name="newMonitor[Path]" value="<?= validHtmlStr($newMonitor['Path']) ?>" size="36"/></td></tr>
-            <tr><td><?= $SLANG['RemoteHostSubPath'] ?></td><td><input type="text" name="newMonitor[SubPath]" value="<?= validHtmlStr($newMonitor['SubPath']) ?>" size="36"/></td></tr>
             <tr><td><?= $SLANG['RemoteImageColours'] ?></td><td><select name="newMonitor[Palette]"><?php foreach ( $remoteColours as $name => $value ) { ?><option value="<?= $value ?>"<?php if ( $value == $newMonitor['Palette'] ) { ?> selected="selected"<?php } ?>><?= $name ?></option><?php } ?></select></td></tr>
 <?php
         }
