@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web timeline view file, $Date: 2008-09-29 09:16:34 +0100 (Mon, 29 Sep 2008) $, $Revision: 2635 $
+// ZoneMinder web timeline view file, $Date: 2009-06-22 12:23:28 +0100 (Mon, 22 Jun 2009) $, $Revision: 2930 $
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -373,7 +373,7 @@ foreach( dbFetchAll( $eventsSql ) as $event )
             }
             else
             {
-                $offset = 1 + ($event['Frames']?((int)($event['Frames']*(($i-$rawStartIndex)/($rawEndIndex-$rawStartIndex)))):0);
+                $offset = 1 + ($event['Frames']?((int)(($event['Frames']-1)*(($i-$rawStartIndex)/($rawEndIndex-$rawStartIndex)))):0);
             }
             $currEventSlots[$i] = array( "count"=>0, "width"=>1, "offset"=>$offset, "event"=>$event );
         }
@@ -823,7 +823,7 @@ xhtmlHeaders(__FILE__, $SLANG['Timeline'] );
             <div id="instruction">
               <p>Pass your mouse over the graph to view a snapshot image and event details.</p>
               <p>Click on the coloured sections of the graph, or the image, to view the event.</p>
-              <p>Click on the background to zoom in to a smaller time period basd around your click.</p>
+              <p>Click on the background to zoom in to a smaller time period based around your click.</p>
               <p>Use the controls below to zoom out or navigate back and forward through the time range.</p>
             </div>
             <div id="eventData">
